# TiendApp Validator - Auxiliar Methods
module TiendappValidator
  def self.root_path(path = nil)
    if path.nil?
      @root_path
    else
      @liquid_files = nil
      @customization_schemas = nil
      @root_path = path
    end
  end

  def self.liquid_files
    @liquid_files ||= get_files(root_path, 'liquid')
  end

  def self.customization_schemas
    @customization_schemas ||= get_files(root_path + 'config/', 'json')
  end

  def self.get_files(path, extension)
    file_paths = []
    Find.find(path) do |p|
      file_paths << p if p =~ /\.(?:#{extension})$/i && !p.include?('/.git/')
    end
    file_paths
  end

  def self.get_content(path)
    file = File.open(path)
    file.read
  end

  def self.get_includes(content)
    expr = /\{\%\s+include\s+[",'](.*)[",']\s+\%\}/
    content.scan(expr)
  end

  def self.get_format(file)
    expr = /\.(\w*)$/
    expr.match(file)[1]
  end

  def self.permit_extension?(file)
    extension = get_format(file)
    EXTENSIONS.include? extension
  end

  def self.validate_extensions
    Find.find(root_path) do |p|
      next unless p.include? '.'
      next if permit_extension? p
      return response 'ERROR', I18n.t('error.not_support_extension', extension: p.split(root_path)[1]), false
    end
    response 'OK', I18n.t('ok.all_support_format'), true
  end

  def self.exist_liquid_file(str)
    path = root_path
    while str.include? '/'
      substring = str.split('/')[0]
      str = str.split('/')[1]
      path = path + substring + '/'
    end
    path + '_' + str + '.liquid'
  end

  def self.response(status, message, valid)
    { status: status,
      message: message,
      valid: valid }
  end
end
