require 'liquid'

# Liquid_validators - containe liquid validation methods
module TiendappValidator
  # VL001 - Validar presencia de los archivos liquid
  def self.validate_liquid_files
    LIQUID_FILES.each do |liquid|
      next if liquid_files.include? root_path + liquid
      return response 'error', I18n.t('error.file_not_found', liquid: liquid), false
    end
    response 'OK', I18n.t('ok.found_all_liquid_files'), true
  end

  # VL002 - Validar vistas parciales liquid
  def self.validate_partial_liquid_files
    file_paths = get_files root_path, 'liquid'
    file_paths.each do |liquid|
      liquid = liquid.split('/').last
      next if LIQUID_FILES.include? liquid
      next if liquid[0] == '_'
      next if (LIQUID_FILES_CHECKOUT + LIQUID_FILES_MAILER).include? liquid
      return response 'error', I18n.t('error.name_invalid', liquid: liquid), false
    end
    response 'OK', I18n.t('ok.partial_liquid_files'), true
  end

  # VL003 - Validar si todas las llamadas a  vistas parciales existen
  def self.validate_folders_liquid_files
    path = root_path
    (LIQUID_FILES_CHECKOUT + LIQUID_FILES_MAILER).each do |liquid|
      next if liquid_files.include? path + CHECKOUT_PATH + liquid
      next if liquid_files.include? path + MAILER_PATH + liquid
      return response 'error', I18n.t('error.file_not_found', liquid: liquid), false
    end
    response 'OK', I18n.t('ok.found_checkout_liquid_files'), true
  end

  # VL004 - Validar si todas las llamadas a  vistas parciales existen
  def self.validate_include_liquid_files
    liquid_files.each do |liquid|
      content = get_content(liquid)
      includes = get_includes(content)
      includes.each do |include|
        unless exist_liquid_file(include[0])
          return response 'error', I18n.t('error.include_not_found', include: include[0]), false
        end
      end
    end
    response 'OK', I18n.t('ok.all_include_exists'), true
  end

  # VL006 - Valida que los archivos tengan sintaxis correcta en Liquid
  def self.validate_liquid_files_syntax
    file_paths = get_files root_path, 'liquid'
    file_paths.each do |liquid|
      next if Liquid::Template.parse(get_content(liquid), error_mode: :strict)
      return response 'error', I18n.t(error.syntax_error, liquid: liquid.split(root_path)[0]), false
    end
    response 'OK', I18n.t('ok.liquid_files_syntax'), true
  end
end
